@@ -236,7 +236,7 @@ class ValueToSPDTO(BaseModel):
 class DataToSPDTO(BaseModel):
     values: List[ValueToSPDTO]
     productGroups: List[ProductGroupJsonDTO]
-    coupledSubsidiesProductGroupsDict: dict[str,str]
+    coupledSubsidiesProductGroupsDict: dict[str,List[str]]
 
 class IntermediateValueFromLP(BaseModel):
     farmId: int
